## Description

Brief description of the changes.

## Type of change

- [ ] Bug fix
- [ ] New tool or feature
- [ ] Documentation
- [ ] Tests
- [ ] Other (describe)

## Checklist

- [ ] Tests pass (`pytest -v`)
- [ ] New tools include tests
- [ ] No breaking changes to existing tools
- [ ] Tool docstrings are clear (they become the LLM-facing description)
